<?php
/**
 * Registering meta boxes
 *
 * In this file, I'll show you how to extend the class to add more field type (in this case, the 'taxonomy' type)
 * All the definitions of meta boxes are listed below with comments, please read them carefully.
 * Note that each validation method of the Validation Class MUST return value instead of boolean as before
 *
 * You also should read the changelog to know what has been changed
 *
 * For more information, please visit: http://www.deluxeblogtips.com/2010/04/how-to-create-meta-box-wordpress-post.html
 *
 */

/********************* BEGIN DEFINITION OF META BOXES ***********************/

// prefix of meta keys, optional
// use underscore (_) at the beginning to make keys hidden, for example $prefix = '_rw_';
// you also can make prefix empty to disable it
$prefix = 'earth_';

$earth_meta_boxes = array();

// meta box ===> HP Highlights
$earth_meta_boxes[] = array(
	'id' => 'hp_highlights_meta',
	'title' => __('HP Highlights Options','earth'),
	'pages' => array('hp_highlights'),

	'fields' => array(
		array(
            'name' => __('URL','earth'),
            'desc' => __('Enter a URL to link the title of this highlight to. Optional.','earth'),
            'id' => $prefix . 'hp_highlights_url',
            'type' => 'text',
            'std' => ''
        ),
	)
);

$months = earth_months();

$time = current_time('timestamp');
$today_day = date('j', $time);
$today_month = date('m', $time);
$today_year = date('Y', $time);

// meta box ===> Events - Options
$earth_meta_boxes[] = array(
	'id' => 'event_options',
	'title' => __('Event Options','earth'),
	'pages' => array('events'),
	'fields' => array(
	array(
            'name' => __('Featured Event?','earth'),
            'desc' => __('Is this a featured event?<br />This setting is used on the homepage event module and event widget.','earth'),
            'id' => $prefix . 'featured_event',
			'type' => 'select',
			'options' => array('no','yes')
        ),
		array(
            'name' => __('Start Date','earth'),
            'desc' => __('Enter the start date for the event.','earth'),
            'id' => $prefix . 'event_start_date',
            'type' => 'date',
            'std' => array(
	            'month' => $today_month,
	            'day' => $today_day,
	            'year' => $today_year,
	        ),
            'options' => array (
            	'month' => $months
            ),
        ),
        array(
            'name' => __('End Date','earth'),
            'desc' => __('Enter the end date for the event.','earth'),
            'id' => $prefix . 'event_end_date',
            'type' => 'date',
            'std' => array(
                'month' => 'Select Month',
                'day' => '',
                'year' => '',
            ),
            'options' => array (
            	'month' => $months
            ),
        ),
        array(
            'name' => __('Start Time','earth'),
            'desc' => __('Enter the start time for the event. (optional) <br /> Use the following format: <strong>09:00 AM</strong>','earth'),
            'id' => $prefix . 'event_start_time',
            'type' => 'text',
            'std' =>'',
        ),
        array(
            'name' => __('End Time','earth'),
            'desc' => __('Enter the end time for the event. (optional) <br /> Use the following format: <strong>09:00 AM</strong>','earth'),
            'id' => $prefix . 'event_end_time',
            'type' => 'text',
            'std' =>'',
        ),
		array(
			'name' => __('Event Details Tab Title','earth'),
			'desc' => __('If you want a title at the top of the event details tab on the post, enter it here.','earth'),
			'id' => $prefix . 'event_details_title',
			'type' => 'text',
			'std' =>'',
			),
        array(
            'name' => __('Google Map Embed Code or Shortcode','earth'),
            'desc' => __('Enter the google maps embed code of the Map tab. When customizing your code use a width of <strong>580px</strong> so it looks best. If you are having issues using the Google Map embed code you can try using a <a href="http://wordpress.org/extend/plugins/search.php?q=google+map+shortcode" target="_blank">shortcode</a>.','earth'),
            'id' => $prefix . 'event_location',
            'type' => 'textarea',
            'std' =>'',
        ),
		array(
			'name' => __('Event Description','earth'),
			'desc' => __('Enter a short description for your event. This is used for the excerpts on the homepage, events page and events widget.','earth'),
			'id' => $prefix . 'event_description',
			'type' => 'textarea',
			'std' =>'',
			),
    ),
    
);

// meta box ===> Slides
$earth_meta_boxes[] = array(
	'id' => 'slides_meta',
	'title' => __('Slide Options','earth'),
	'pages' => array('slides'),
	'fields' => array(
		array(
            'name' => __('Caption','earth'),
            'desc' => __('Enter a description for your slide.','earth'),
            'id' => $prefix . 'slides_description',
            'type' => 'textarea',
            'std' => ''
        ),
		array(
            'name' => __('Slide URL','earth'),
            'desc' => __('Enter a URL to link this slide to.','earth'),
            'id' => $prefix . 'slides_url',
            'type' => 'text',
            'std' => ''
        ),
		array(
            'name' => __('Slider URL Target','earth'),
            'desc' => __('Select your slide URL target.','earth'),
            'id' => $prefix . 'slides_url_target',
			'type' => 'select',
			'options' => array('self','blank')
        ),
		array(
            'name' => __('Video Embed Code','earth'),
            'desc' => __('Enter your youtube/vimeo or other embed code here.<br /><strong>Important:</strong> Width should be 940px and height should be 400px to fit perfectly in the slider.','earth'),
            'id' => $prefix . 'slides_video',
            'type' => 'textarea',
            'std' => ''
        ),
	)
);

// meta box ===> Page Options
$earth_meta_boxes[] = array(
	'id' => 'page_template_options',
	'title' => __('Page Options','earth'),
	'pages' => array('page'),
	'context' => 'normal',
	'priority' => 'high',
	'fields' => array(
		array(
			'name' => __('Image Slider', 'earth'),
			'id' => $prefix . 'img_slider_cat',
			'type' => 'slider_cat',
			'desc' => __('Select an image slider if you want one at the top of the page.', 'earth')
		),
		array(
            'name' => __('Flickr SlideShow URL','earth'),
            'desc' => __('Enter the URL to a flickr slideshow if you want one at top of your page.','earth'),
            'id' => $prefix . 'flickr_show',
			'type' => 'text'
        ),
		array(
            'name' => __('Enable/Disable Main Title','earth'),
            'desc' => __('Select to enable disable the main title.','earth'),
            'id' => $prefix . 'page_title',
			'type' => 'select',
			'options' => array('Enable','Disable')
        ),
		array(
			'name' => __('Blog Template Category', 'earth'),
			'id' => $prefix . 'blog_parent',
			'type' => 'blog_cat',
			'desc' => __('Select a category for your blog page.', 'earth')
		),
		array(
			'name' => __('Gallery Template Category', 'earth'),
			'id' => $prefix . 'gallery_parent',
			'type' => 'gallery_cat',
			'desc' => __('Select a category for your gallery page.', 'earth')
		)
	)
);

foreach ($earth_meta_boxes as $meta_box) {
	new earth_meta_box($meta_box);
}
?>