<?php
/**
 * @package WordPress
 * @subpackage Earth Theme
 */
global $data; //get theme options ?>

<!doctype html>
<html <?php language_attributes(); ?>>
<head>

    <meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php bloginfo('charset'); ?>" />
    
    <!-- Fix Ipad Viewport Issue
    ================================================== -->
    <meta name="viewport" content="width=1060, maximum-scale=1.0" />
    
    <!-- Title Tag
    ================================================== -->
    <title><?php wp_title(''); ?><?php if(wp_title('', false)) { echo ' |'; } ?> <?php bloginfo('name'); ?></title>
    
    <!-- Favicon
    ================================================== -->
    <?php if(!empty($data['custom_favicon'])) { ?><link rel="icon" type="image/png" href="<?php echo $data['custom_favicon']; ?>" /><?php } ?>
    
    <!-- Main CSS
    ================================================== -->
    <link rel="stylesheet" type="text/css" href="<?php bloginfo('stylesheet_url'); ?>" />
    
    <!--[if IE 8]>
        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/ie8.css" media="screen" />
    <![endif]-->
    
    <!--[if IE 7]>
        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/ie7.css" media="screen" />
        <link rel="stylesheet" type="text/css" href="<?php echo get_template_directory_uri(); ?>/css/awesome-font-ie7.css" media="screen" />
    <![endif]-->
    
    <!-- Load HTML5 dependancies for IE
    ================================================== -->
    <!--[if IE]>
        <script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script><![endif]-->
    <!--[if lte IE 7]>
        <script src="js/IE8.js" type="text/javascript"></script><![endif]-->
    <!--[if lt IE 7]>
        <link rel="stylesheet" type="text/css" media="all" href="css/ie6.css"/>
    <![endif]-->
    
    <!-- WP Head
    ================================================== -->
    <?php
    //Custom Google Fonts
    get_template_part( 'includes/custom-fonts');
    
    //WordPrress Header Hook <=== do not delete!
    wp_head();
    
    //show tracking code - header 
    echo stripslashes($data['tracking_header']);  ?>

</head>


<!-- Begin Body
================================================== -->
<body <?php body_class(); ?>>

<header id="masterhead" class="clearfix">

	<?php
    if($data['enable_disable_social'] !='disable') {
    //get social links
    $social_links = array('twitter','flickr','google','facebook','youtube','vimeo','calendar','contact','rss');
    ?>
    <ul id="mastersocial" class="clearfix">
        <?php
        //social loop
        foreach($social_links as $social_link) {
            if(!empty($data[$social_link])) {
                echo '<li><a href="'. $data[$social_link] .'" title="'. $social_link .'" target="_blank"><img src="'. get_template_directory_uri() .'/images/social/'.$social_link.'.png" alt="'. $social_link .'" /></a></li>';
        } }
        ?>
    </ul>
    <!-- /mastersocial -->
    <?php } ?>
        
    <div id="logo">
        <?php if($data['custom_logo'] !='') { ?>
            <a href="<?php echo home_url(); ?>/" title="<?php bloginfo('name'); ?>" rel="home"><img src="<?php echo $data['custom_logo']; ?>" alt="<?php bloginfo( 'name' ) ?>" /></a>
        <?php } else { ?>
            <a href="<?php echo home_url(); ?>/" title="<?php bloginfo('name'); ?>" rel="home" class="text-logo"><?php bloginfo('name'); ?></a>
        <?php } ?>
    </div>
    <!-- /logo -->

	<?php
	//show callout button
	if(!empty($data['callout_link'])) { ?>
		<a href="<?php echo $data['callout_link']; ?>" id="header-donate" title="<?php echo $data['callout_text']; ?>" target="_<?php echo $data['callout_target']; ?>">
            <div id="header-donate-inner">
            	<?php if($data['callout_icon'] !='Select') { ?>
                <span class="awesome-icon-<?php echo $data['callout_icon']; ?>"></span>
                <?php } ?>
                <?php echo $data['callout_text']; ?>
            </div>
            <!-- /header-donate-inner -->
        </a>
        <!-- /header-donate -->
	<?php } ?>
    
</header><!-- /masterhead -->
  
<div id="wrapper" class="clearfix">

	<nav id="mainnav">
        <?php
		//show main nav
        wp_nav_menu( array(
            'theme_location' => 'main_menu',
            'sort_column' => 'menu_order',
            'menu_class' => 'sf-menu clearfix'
        ));
        //show search box
        if($data['disable_search'] !='disable') get_search_form(); ?>   
    </nav>
    <!-- /mainnav -->

	<?php
	//show homepage slider
    if(is_front_page()) {
        //show home slider
        get_template_part( 'includes/home/slides');
    }

    global $post;
    if( is_page() && !is_front_page() ) {
        //get image slider meta
        $img_slider_cat = get_post_meta($post->ID, 'earth_img_slider_cat', TRUE);
        
        //show img slider if the meta isn't empty and a category has been selected
        if(!empty($img_slider_cat) && $img_slider_cat != 'select_slider_cat'){
            
            //get template file that includes slider code
            get_template_part( 'includes/img-slider');
        }
		
		//flickr slideshow
		$earth_flickr_show = get_post_meta($post->ID, 'earth_flickr_show', TRUE);
		if($earth_flickr_show){
			global $wp_embed;
			echo '<div id="flickr-slideshow-wrap">' . $wp_embed->shortcode( array( "width" => 940, "height" => 400 ), $earth_flickr_show ) . '</div>';
		}
		
    } ?>