<?php
/**
 * @package WordPress
 * @subpackage Earth Theme
*/


// Set the content width based on the theme's design and stylesheet.
if (!isset($content_width)) $content_width = 980;

/*-----------------------------------------------------------------------------------*/
/*	Remove junk from head & add junk?
/*-----------------------------------------------------------------------------------*/

/*remove*/
remove_action('wp_head', 'rsd_link');
remove_action('wp_head', 'wp_generator');
remove_action('wp_head', 'feed_links', 2);
remove_action('wp_head', 'index_rel_link');
remove_action('wp_head', 'wlwmanifest_link');
remove_action('wp_head', 'feed_links_extra', 3);
remove_action('wp_head', 'start_post_rel_link', 10, 0);
remove_action('wp_head', 'parent_post_rel_link', 10, 0);
remove_action('wp_head', 'adjacent_posts_rel_link', 10, 0);

/*add - to make theme check happy*/
add_theme_support('automatic-feed-links');


/*-----------------------------------------------------------------------------------*/
/*	Images
/*-----------------------------------------------------------------------------------*/
if (function_exists('add_theme_support')) {
	add_theme_support( 'post-thumbnails');
}

if (function_exists( 'add_image_size')) {	
	/*add image size*/
	add_image_size( 'full-size',  9999, 9999, false );
	add_image_size( 'small-thumb',  60, 60, true );
}
//better jpg quality
add_filter( 'jpeg_quality', 'earth_jpeg_quality' );
function earth_jpeg_quality( $quality ) { return 100; }

/*-----------------------------------------------------------------------------------*/
/*	Javascsript
/*-----------------------------------------------------------------------------------*/

add_action('wp_enqueue_scripts','earth_scripts_function');
function earth_scripts_function() {
	
	if(get_option(OPTIONS)) {
		global $data; //get theme options
	}
	
	//enqueue jQuery
	wp_enqueue_script('jquery');
	wp_enqueue_script('jquery-ui-accordion');
	wp_enqueue_script('jquery-ui-tabs');
	
	//site wide js
	wp_enqueue_script('hoverIntent', get_template_directory_uri() . '/js/jquery.hoverIntent.minified.js', array('jquery'), '', true);
	wp_enqueue_script('superfish', get_template_directory_uri() . '/js/jquery.superfish.js', array('jquery'), '', true);
	wp_enqueue_script('view', get_template_directory_uri() . '/js/view.min.js?auto', array('jquery'), '1.2', true);
	wp_enqueue_script('easing', get_template_directory_uri() . '/js/jquery.easing.1.3.js', array('jquery'), '1.3', true);
	wp_enqueue_script('slides', get_template_directory_uri() . '/js/slides.min.jquery.js', array('jquery', 'easing'), '1.1.9', true);
	wp_enqueue_script('tipsy', get_template_directory_uri() . '/js/jquery.tipsy.js', array('jquery'), '1.0', true);
	wp_enqueue_script('faqs-init', get_template_directory_uri() . '/js/jquery.faqs.init.js', array('jquery'), '1.0', true);
	
	//gallery with Filter
	if(is_page_template('template-gallery-filter.php')) {
		wp_enqueue_script('isotope', get_template_directory_uri() . '/js/jquery.isotope.min.js', array('jquery','easing'), '1.5.19', true);
		wp_enqueue_script('isotope-gallery', get_template_directory_uri() . '/js/isotope_gallery.js', array('jquery','easing','isotope'), '1.0', true);
	}
	
	
	//caledar template
	if(is_page_template('template-events-calendar.php')) {
		/**custom drop-down - maybe to be used in potential theme update.
		wp_enqueue_script('dropkick', get_template_directory_uri() . '/js/jquery.dropkick-1.0.0.js',array('jquery'), '1.0', true);
		*/
		wp_enqueue_script('calendar', get_template_directory_uri() . '/js/calendar.js', array('jquery'), '', true);
	}
	
	//threaded comments js
	if(is_single() || is_page()) {
		 wp_enqueue_script('comment-reply');
	}
	
	//js init
	wp_enqueue_script('earth-init', get_template_directory_uri() . '/js/jquery.init.js', array('jquery','jquery-ui-core','jquery-ui-accordion'), '', true);
	
	//setup vars for use in calendar scripts
	$params = '';
	$params = array(
	  'templateurl' => trailingslashit(get_bloginfo('template_url')),
	  'ajaxurl' => admin_url( 'admin-ajax.php' ),
	); 
	wp_localize_script( 'calendar', 'aqvars', $params );

}


/*-----------------------------------------------------------------------------------*/
/*Enqueue CSS
/*-----------------------------------------------------------------------------------*/
add_action('wp_enqueue_scripts', 'earth_enqueue_css');
function earth_enqueue_css() {
	
	//awesome font - icon fonts
	wp_enqueue_style('awesome-font', get_template_directory_uri() . '/css/awesome-font.css', 'style');
	
	/**custom drop-down - maybe to be used in potential theme update.
	if(is_page_template('template-events-calendar.php')) {
		wp_enqueue_style('dropkick', get_template_directory_uri() . '/css/dropkick.css', 'style');	
	}
	*/
	
}


/*-----------------------------------------------------------------------------------*/
/*	Output Custom CSS Into Header
/*-----------------------------------------------------------------------------------*/

add_action('wp_head', 'earth_custom_css');
function earth_custom_css() {
	
		if(get_option(OPTIONS)) {
			global $data; //get theme options
		}
		
		$custom_css ='';
		
		/**custom css field**/
		if(!empty($data['custom_css'])) {
			$custom_css .= $data['custom_css'];
		}
		
		//background
		if(!empty($data['custom_bg'])) {
			if($data['custom_bg'] !=''.get_template_directory_uri().'/images/bg/0.png') {
				$custom_css .= 'body{background-image: url('.$data['custom_bg'].');}';
			}
		}
		if(!empty($data['background_color'])) {
			$custom_css .= 'body{background-color: '.$data['background_color'].';}';
		}
		
		//header padding
		if($data['header_top_padding'] !='25px') {
			$custom_css .= '#masterhead{padding-top: '.$data['header_top_padding'].';}';
		}
		if(!empty($data['header_bottom_padding'])) {
			$custom_css .= '#masterhead{padding-bottom: '.$data['header_bottom_padding'].';}';
		}
		
		//header aside top value
		if(!empty($data['header_aside_top'])) {
			$custom_css .= '#masterhead-aside{top: '.$data['header_aside_top'].';}';
		}
		
		//Font Variables
		$body_font = $data['body_font'];
		$headings_font = $data['headings_font'];
		$donate_font = $data['donate_font'];
		$navigation_font = $data['navigation_font'];
		$slider_caption_font = $data['slider_caption_font'];
		
		//font face-types
		if($body_font['face'] && $body_font['face'] != 'default'){
			$custom_css .= 'body{font-family: '.$body_font['face'].';}';
		}	
			
		if($headings_font['face'] && $headings_font['face'] != 'default'){
			$custom_css .= 'h1,h2,h3,h4,h5,h6, #page-heading{font-family: '.$headings_font['face'].' !important;}';
		}
		
		if($donate_font['face'] && $donate_font['face'] != 'default'){
			$custom_css .= '#header-donate, #header-donate a{font-family: '.$donate_font['face'].' !important;}';
		}
		
		if($navigation_font['face'] && $navigation_font['face'] != 'default'){
			$custom_css .= '#mainnav{font-family: '.$navigation_font['face'].' !important;}';
		}	
		
		if($slider_caption_font['face'] && $slider_caption_font['face'] != 'default'){
			$custom_css .= '#slider .caption{font-family: '.$slider_caption_font['face'].' !important;}';
		}
		
		//font weights
		if($body_font['style'] == 'italic'){
			$custom_css .= 'body{font-style: italic; font-weight: normal;}';
		}
		if($body_font['style'] == 'bold'){
			$custom_css .= 'body{font-weight: bold;}';
		}
		if($body_font['style'] == 'bold italic'){
			$custom_css .= 'body{font-weight: bold;font-style: italic;}';
		}
		
		
		if($headings_font['style'] == 'normal'){
			$custom_css .= 'h1,h2,h3,h4,h5,h6,h2 a,h3 a,h4 a{font-weight: normal !important;}';
		}
		if($headings_font['style'] == 'italic'){
			$custom_css .= 'h1,h2,h3,h4,h5,h6,h2 a,h3 a,h4 a{font-style: italic; font-weight: nomal !important;}';
		}
		if($headings_font['style'] == 'bold italic'){
			$custom_css .= 'h1,h2,h3,h4,h5,h6,h2 a,h3 a,h4 a{font-weight: bold;font-style: italic !important;}';
		}
		
		
		if($donate_font['style'] == 'normal'){
			$custom_css .= '#header-donate{font-weight: normal;}';
		}
		if($donate_font['style'] == 'italic'){
			$custom_css .= '#header-donate{font-style: italic; font-weight: normal;}';
		}
		if($donate_font['style'] == 'bold italic'){
			$custom_css .= '#header-donate{font-weight: bold;font-style: italic;}';
		}
		
		
		if($navigation_font['style'] == 'italic'){
			$custom_css .= '#mainnav,#mainnav a{font-style: italic; font-weight: normal;}';
		}
		if($navigation_font['style'] == 'normal'){
			$custom_css .= '#mainnav, #mainnav a{font-weight: normal;}';
		}
		if($navigation_font['style'] == 'bold italic'){
			$custom_css .= '#mainnav, #mainnav a{font-weight: bold;font-style: italic;}';
		}
		
		
		if($slider_caption_font['style'] == 'normal'){
			$custom_css .= '#slider .caption{font-weight: normal;}';
		}
		if($slider_caption_font['style'] == 'italic'){
			$custom_css .= '#slider .caption{font-style: italic; font-weight: normal;}';
		}
		if($slider_caption_font['style'] == 'bold'){
			$custom_css .= '#slider .caption{font-weight: bold;}';
		}
		if($slider_caption_font['style'] == 'bold italic'){
			$custom_css .= '#slider .caption{font-weight: bold;font-style: italic;}';
		}
		
		//font sizes
		if($donate_font['size'] != '13px'){
			$custom_css .= 'a#header-donate{font-size: '.$donate_font['size'].';}';
		}
		
		if($navigation_font['size'] != '13px'){
			$custom_css .= '#mainnav .sf-menu a{font-size: '.$navigation_font['size'].';}';
		}
		
		if($slider_caption_font['size'] != '14px'){
			$custom_css .= '#slider .caption{font-size: '.$slider_caption_font['size'].';}';
		}

		/**echo all css**/
		$css_output = "<!-- Custom CSS -->\n<style type=\"text/css\">\n" . $custom_css . "\n</style>";
		
		if(!empty($custom_css)) {
			echo $css_output;
		}
}


/*-----------------------------------------------------------------------------------*/
/*	Sidebars
/*-----------------------------------------------------------------------------------*/

//Register Sidebars
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => __('Right Sidebar','earth'),
		'id' => 'sidebar',
		'description' => __('Widgets in this area will be shown in the sidebar.','earth'),
		'before_widget' => '<div class="sidebar-box %2$s clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4><span>',
		'after_title' => '</span></h4>',
));
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => __('Footer First','earth'),
		'id' => 'footer-widget-first',
		'description' => __('Widgets in this area will be shown in the first footer column','earth'),
		'before_widget' => '<div class="footer-widget %2$s clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
));
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => __('Footer Second','earth'),
		'id' => 'footer-widget-second',
		'description' => __('Widgets in this area will be shown in the second footer column.','earth'),
		'before_widget' => '<div class="footer-widget %2$s clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
));
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => __('Footer Third','earth'),
		'id' => 'footer-widget-third',
		'description' => __('Widgets in this area will be shown in the third footer column.','earth'),
		'before_widget' => '<div class="footer-widget %2$s clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
));
if ( function_exists('register_sidebar') )
	register_sidebar(array(
		'name' => __('Footer Fourth','earth'),
		'id' => 'footer-widget-fourth',
		'description' => __('Widgets in this area will be shown in the fourth footer column.','earth'),
		'before_widget' => '<div class="footer-widget %2$s clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>',
));


/*-----------------------------------------------------------------------------------*/
/*	Custom Post Types & Taxonomies
/*-----------------------------------------------------------------------------------*/

add_action( 'init', 'earth_create_post_types' );
function earth_create_post_types() {

	//image slides post type
	register_post_type( 'slides',
		array(
		  'labels' => array(
			'name' => __( 'Slides', 'earth' ),
			'singular_name' => __( 'Slide', 'earth' ),		
			'add_new' => _x( 'Add New', 'Slide', 'earth' ),
			'add_new_item' => __( 'Add New Slide', 'earth' ),
			'edit_item' => __( 'Edit Slide', 'earth' ),
			'new_item' => __( 'New Slide', 'earth' ),
			'view_item' => __( 'View Slide', 'earth' ),
			'search_items' => __( 'Search Slides', 'earth' ),
			'not_found' =>  __( 'No Slides found', 'earth' ),
			'not_found_in_trash' => __( 'No Slides Found In Trash', 'earth' ),
			'parent_item_colon' => ''
			
		  ),
		  'public' => true,
		  'supports' => array('title','thumbnail'),
		  'query_var' => true,
		  'show_in_nav_menus' => false,
		  'exclude_from_search' => true,
		  'menu_icon' => get_template_directory_uri() . '/images/admin/icon-slider.png',
		)
	  );
	  
	//hp highlights
	register_post_type( 'hp_highlights',
		array(
		  'labels' => array(
			'name' => __( 'HP Highlights', 'earth' ),
			'singular_name' => __( 'Highlight', 'earth' ),		
			'add_new' => _x( 'Add New', 'Highlight', 'earth' ),
			'add_new_item' => __( 'Add New Highlight', 'earth' ),
			'edit_item' => __( 'Edit Highlight', 'earth' ),
			'new_item' => __( 'New Highlight', 'earth' ),
			'view_item' => __( 'View Highlight', 'earth' ),
			'search_items' => __( 'Search Highlights', 'earth' ),
			'not_found' =>  __( 'No Highlights Found', 'earth' ),
			'not_found_in_trash' => __( 'No Highlights Found In Trash', 'earth' ),
			'parent_item_colon' => ''
			
		  ),
		  'public' => true,
		  'supports' => array('title','editor','thumbnail', 'revisions'),
		  'query_var' => true,
		  'rewrite' => array( 'slug' => 'hp-highlights' ),
		  'show_in_nav_menus' => false,
		  'exclude_from_search' => true,
		  'menu_icon' => get_template_directory_uri() . '/images/admin/icon-highlights.png',
		)
	  );
	  
	// Gallery
	register_post_type( 'gallery',
		array(
		  'labels' => array(
			'name' => __( 'Gallery','earth' ),
			'singular_name' => __( 'Gallery','earth' ),		
			'add_new' => _x( 'Add New', 'Gallery','earth' ),
			'add_new_item' => __( 'Add New Gallery','earth' ),
			'edit_item' => __( 'Edit Gallery','earth' ),
			'new_item' => __( 'New Gallery','earth' ),
			'view_item' => __( 'View Gallery','earth' ),
			'search_items' => __( 'Search Galleries','earth' ),
			'not_found' =>  __( 'No Galleries found','earth' ),
			'not_found_in_trash' => __( 'No Galleries Found In Trash','earth' ),
			'parent_item_colon' => ''
			
		  ),
		  'public' => true,
		  'exclude_from_search' => false,
		  'supports' => array('title','editor','thumbnail','revisions'),
		  'menu_icon' => get_template_directory_uri() . '/images/admin/icon-gallery.png',
		  'query_var' => true,
		  'rewrite' => array( 'slug' => 'gallery' ),
		)
  	);
	
	// Events
	register_post_type( 'events',
		array(
		  'labels' => array(
			'name' => __( 'Events','earth' ),
			'singular_name' => __( 'Event','earth' ),		
			'add_new' => _x( 'Add New', 'Event','earth' ),
			'add_new_item' => __( 'Add New Event','earth' ),
			'edit_item' => __( 'Edit Event','earth' ),
			'new_item' => __( 'New Event','earth' ),
			'view_item' => __( 'View Event','earth' ),
			'search_items' => __( 'Search Events','earth' ),
			'not_found' =>  __( 'No Events Found','earth' ),
			'not_found_in_trash' => __( 'No Events Found In Trash','earth' ),
			'parent_item_colon' => ''
			
		  ),
		  'public' => true,
		  'exclude_from_search' => false,
		  'supports' => array('title','editor','thumbnail','revisions'),
		  'menu_icon' => get_template_directory_uri() . '/images/admin/icon-events.png',
		  'query_var' => true,
		  'rewrite' => array( 'slug' => 'event' ),
		)
  	);

	// FAQs
	register_post_type( 'faqs',
		array(
		  'labels' => array(
			'name' => __( 'FAQs','earth' ),
			'singular_name' => __( 'FAQ','earth' ),		
			'add_new' => _x( 'Add New', 'FAQ','earth' ),
			'add_new_item' => __( 'Add New FAQ','earth' ),
			'edit_item' => __( 'Edit FAQ','earth' ),
			'new_item' => __( 'New FAQ','earth' ),
			'view_item' => __( 'View FAQ','earth' ),
			'search_items' => __( 'Search FAQs','earth' ),
			'not_found' =>  __( 'No FAQs Found','earth' ),
			'not_found_in_trash' => __( 'No FAQs Found In Trash','earth' ),
			'parent_item_colon' => ''
			
		  ),
		  'public' => true,
		  'exclude_from_search' => false,
		  'supports' => array('title','editor', 'revisions'),
		  'menu_icon' => get_template_directory_uri() . '/images/admin/icon-faqs.png',
		  'query_var' => true,
		  'rewrite' => array( 'slug' => 'faqs' ),
		)
  	);

}


// Add taxonomies
add_action( 'init', 'earth_create_taxonomies' );
function earth_create_taxonomies() {
	
	// gallery taxonomies
	$gallery_cat_labels = array(
		'name' => __( 'Gallery Categories', 'earth' ),
		'singular_name' => __( 'Gallery Category', 'earth' ),
		'search_items' =>  __( 'Search Gallery Categories', 'earth' ),
		'all_items' => __( 'All Gallery Categories', 'earth' ),
		'parent_item' => __( 'Parent Gallery Category', 'earth' ),
		'parent_item_colon' => __( 'Parent Gallery Category:', 'earth' ),
		'edit_item' => __( 'Edit Gallery Category', 'earth' ),
		'update_item' => __( 'Update Gallery Category', 'earth' ),
		'add_new_item' => __( 'Add New Gallery Category', 'earth' ),
		'new_item_name' => __( 'New Gallery Category Name', 'earth' ),
		'choose_from_most_used'	=> __( 'Choose from the most used gallery categories', 'earth' )
	); 	

	register_taxonomy('gallery_cats','gallery',array(
		'public' => true,
		'hierarchical' => true,
		'labels' => $gallery_cat_labels,
		'query_var' => true,
		'show_in_nav_menus' => true,
		'rewrite' => array( 'slug' => 'gallery-category' ),
	));
	
	// FAQs taxonomies
	$faqs_cat_labels = array(
		'name' => __( 'Topics', 'earth' ),
		'singular_name' => __( 'Topic', 'earth' ),
		'search_items' =>  __( 'Search Topics', 'earth' ),
		'all_items' => __( 'All Topics', 'earth' ),
		'parent_item' => __( 'Parent Topics', 'earth' ),
		'parent_item_colon' => __( 'Parent Topics:', 'earth' ),
		'edit_item' => __( 'Edit Topics', 'earth' ),
		'update_item' => __( 'Update Topics', 'earth' ),
		'add_new_item' => __( 'Add New Topics', 'earth' ),
		'new_item_name' => __( 'New Topics', 'earth' ),
		'choose_from_most_used'	=> __( 'Choose from the most used faq categories', 'earth' )
	); 	

	register_taxonomy('faq_cats','faqs',array(
		'hierarchical' => true,
		'labels' => $faqs_cat_labels,
		'query_var' => true,
		'show_in_nav_menus' => true,
		'rewrite' => array( 'slug' => 'faqs-category' ),
	));
		
	// Image slide taxonomies
	$service_cat_labels = array(
		'name' => __( 'Sliders', 'earth' ),
		'singular_name' => __( 'Slider', 'earth' ),
		'search_items' =>  __( 'Search Sliders', 'earth' ),
		'all_items' => __( 'All Sliders', 'earth' ),
		'edit_item' => __( 'Edit Slider', 'earth' ),
		'update_item' => __( 'Update Slider', 'earth' ),
		'add_new_item' => __( 'Add New Slider', 'earth' ),
		'new_item_name' => __( 'New Slider', 'earth' ),
		'choose_from_most_used'	=> __( 'Choose from the most used sliders', 'earth' )
	); 	

	register_taxonomy('img_sliders','slides',array(
		'hierarchical' => true,
		'labels' => $service_cat_labels,
		'query_var' => true,
		'show_in_nav_menus' => false,
		'show_tagcloud' => false
	));
	
}

/*-----------------------------------------------------------------------------------*/
/*	Tagcloud Filter
/*-----------------------------------------------------------------------------------*/

add_filter( 'widget_tag_cloud_args', 'earth_custom_tag_cloud_widget' );
function earth_custom_tag_cloud_widget($args) {
	$args['largest'] = 12; //largest tag
	$args['smallest'] = 12; //smallest tag
	$args['unit'] = 'px'; //tag font unit
	$args['format'] = 'list'; //ul with a class of wp-tag-cloud
	return $args;
}

/*-----------------------------------------------------------------------------------*/
/*	Post Type Pagination
/*-----------------------------------------------------------------------------------*/

// Set number of posts per page for taxonomy pages
$option_posts_per_page = get_option('posts_per_page');
add_action( 'init', 'my_modify_posts_per_page', 0);
function my_modify_posts_per_page() {
    add_filter( 'option_posts_per_page', 'my_option_posts_per_page' );
}
function my_option_posts_per_page( $value ) {
	global $data;
	global $option_posts_per_page;
	
	// Get theme panel admin
    if (is_tax( 'gallery_cats') ) {
        return '12';
    }
	if (is_search()) {
		return 10;
	}
	else {
        return $option_posts_per_page;
    }
}


/*-----------------------------------------------------------------------------------*/
/*	Custom Login Logo
/*-----------------------------------------------------------------------------------*/
function earth_custom_login_logo() {
    global $data;
    if($data['custom_login_logo'] !='') {
        $custom_login_logo_css = '';
        $custom_login_logo_css .= '<style type="text/css">';
        $custom_login_logo_css .= '.login h1 a {';
        $custom_login_logo_css .= 'background-image:url('. $data['custom_login_logo'] .') !important;width: auto !important;background-size: auto !important;';
        if($data['custom_login_logo_height']) {
            $custom_login_logo_css .= 'height: '.$data['custom_login_logo_height'].' !important;';
        }
        $custom_login_logo_css .= '}</style>';

        echo $custom_login_logo_css;
    }
}

add_action('login_head', 'earth_custom_login_logo');


/*-----------------------------------------------------------------------------------*/
/*	Add taxonomy filter
/*-----------------------------------------------------------------------------------*/
function earth_add_taxonomy_filters() {
	global $typenow;

	// must set this to the post type you want the filter(s) displayed on
	if($typenow == 'gallery' ){
		
		// an array of all the taxonomyies you want to display. Use the taxonomy name or slug
		if( $typenow == 'gallery') { $taxonomies = array('gallery_cats'); }
 
		foreach ($taxonomies as $tax_slug) {
			$tax_obj = get_taxonomy($tax_slug);
			$tax_name = $tax_obj->labels->name;
			$terms = get_terms($tax_slug);
			if(count($terms) > 0) {
				echo "<select name='$tax_slug' id='$tax_slug' class='postform'>";
				echo "<option value=''>".__('All Categories','earth')."</option>";
				foreach ($terms as $term) { 
					echo '<option value='. $term->slug, $_GET[$tax_slug] == $term->slug ? ' selected="selected"' : '','>' . $term->name .' (' . $term->count .')</option>'; 
				}
				echo "</select>";
			}
		}
	}
}
add_action( 'restrict_manage_posts', 'earth_add_taxonomy_filters' );


/*-----------------------------------------------------------------------------------*/
/*	Other functions
/*-----------------------------------------------------------------------------------*/

// Limit Post Word Count For Blog Posts
add_filter('excerpt_length', 'earth_excerpt_length');
function earth_excerpt_length($length) {
	global $data;
	return $data['blog_excerpt'];
}


//Replace Excerpt Link for the blog
add_filter('excerpt_more', 'new_excerpt_more');
	function new_excerpt_more($more) {
		global $post;
		if(!is_search()) {
			return '...<br /><a href="'. get_permalink($post->ID) . '" class="read-more">'. __('continue reading','earth') .'</a>';
		}
	}

// Enable Custom Background
add_theme_support( 'custom-background');

// register navigation menus
register_nav_menus(
	array(
		'main_menu' => __('Main','earth'),
		'footer_menu' => __('Footer','earth')
	)
);

/// add home link to menu
add_filter( 'wp_page_menu_args', 'home_page_menu_args' );
function home_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}

// Localization Support
load_theme_textdomain( 'earth', TEMPLATEPATH.'/lang' );

// functions run on activation --> important flush to clear rewrites
if ( is_admin() && isset($_GET['activated'] ) && $pagenow == 'themes.php' ) {
	$wp_rewrite->flush_rules();
}

/*-----------------------------------------------------------------------------------*/
// Options Framework - SMOF
/*-----------------------------------------------------------------------------------*/
require_once ('admin/index.php');

//common functions
require_once('functions/better-comments.php');
require_once('functions/pagination.php');
require_once('functions/shortcodes.php');
require_once('functions/aqua-resizer.php');
require_once('functions/calendar.php');

//widgets
require_once('functions/widgets/recent-posts.php');
require_once('functions/widgets/flickr-widget.php');
require_once('functions/widgets/recent-gallery.php');
require_once('functions/widgets/featured-events.php');

// Load files ONLY in the back-end
if ( defined( 'WP_ADMIN' ) && WP_ADMIN ) {
	require_once('functions/meta/meta-box-class.php');
	require_once('functions/meta/meta-box-usage.php');
	require_once('mce/shortcode-popup.php');
	require_once('functions/custom-editor-columns.php');
}

/*-----------------------------------------------------------------------------------*/
// Save The ID's of past events
/*-----------------------------------------------------------------------------------*/

function wpex_get_expired_events_ids() {
	
	// Setup array for the ids
	$ids = array();
	
	// Query Events
	$custom_query = new WP_Query( array(
		'post_type' => array( 'events' ),
		'nopaging' => true,
		'posts_per_page' => '-1'
	));
	
	// Loop through events
	while($custom_query->have_posts()) : $custom_query->the_post();
	
		//end date
		$end_date = get_post_meta(get_the_ID(), 'earth_event_end_date', TRUE);
		
		//current date
		$end_date = mktime(0,0,0,$end_date['month'],$end_date['day'],$end_date['year']);
		$today = mktime(0,0,0,date("m"),date("d"),date("Y"));
		
		// Check if event has passed
		if ( $end_date < $today ) {

			// Save the ID to exclude
			$ids[] = get_the_ID();
		
		}
	
	endwhile;  wp_reset_postdata(); // reset the query
	
	return $ids;
} ?>